==> metricflow-0.200.0.dev5-py3-none-any.whl: metricflow/test/snapshots/test_dataflow_to_sql_plan.py/SqlQueryPlan/BigQuery/test_multi_hop_to_scd_dimension__plan0_optimized.sql <==
-- Join Standard Outputs
-- Pass Only Elements:
--   ['bookings', 'listing__lux_listing__is_confirmed_lux', 'metric_time']
-- Aggregate Measures
-- Compute Metrics via Expressions
SELECT
  subq_13.metric_time AS metric_time
  , subq_18.lux_listing__is_confirmed_lux AS listing__lux_listing__is_confirmed_lux
  , SUM(subq_13.bookings) AS bookings
FROM (
  -- Read Elements From Semantic Model 'bookings_source'
  -- Metric Time Dimension 'ds'
  -- Pass Only Elements:
  --   ['bookings', 'metric_time', 'listing']
  SELECT
    ds AS metric_time
    , listing_id AS listing
    , 1 AS bookings
  FROM ***************************.fct_bookings bookings_source_src_10015
) subq_13
LEFT OUTER JOIN (
  -- Join Standard Outputs
  -- Pass Only Elements:
  --   ['lux_listing__is_confirmed_lux',
  --    'lux_listing__window_start',
  --    'lux_listing__window_end',
  --    'listing']
  SELECT
    lux_listings_src_10019.valid_from AS lux_listing__window_start
    , lux_listings_src_10019.valid_to AS lux_listing__window_end
    , lux_listing_mapping_src_10018.listing_id AS listing
    , lux_listings_src_10019.is_confirmed_lux AS lux_listing__is_confirmed_lux
  FROM ***************************.dim_lux_listing_id_mapping lux_listing_mapping_src_10018
  LEFT OUTER JOIN
    ***************************.dim_lux_listings lux_listings_src_10019
  ON
    lux_listing_mapping_src_10018.lux_listing_id = lux_listings_src_10019.lux_listing_id
) subq_18
ON
  (
    subq_13.listing = subq_18.listing
  ) AND (
    (
      subq_13.metric_time >= subq_18.lux_listing__window_start
    ) AND (
      (
        subq_13.metric_time < subq_18.lux_listing__window_end
      ) OR (
        subq_18.lux_listing__window_end IS NULL
      )
    )
  )
GROUP BY
  metric_time
  , listing__lux_listing__is_confirmed_lux

==> metricflow-0.202.0-py3-none-any.whl: metricflow/test/snapshots/test_dataflow_to_sql_plan.py/SqlQueryPlan/BigQuery/test_multi_hop_to_scd_dimension__plan0_optimized.sql <==
-- Join Standard Outputs
-- Pass Only Elements:
--   ['bookings', 'listing__lux_listing__is_confirmed_lux', 'metric_time__day']
-- Aggregate Measures
-- Compute Metrics via Expressions
SELECT
  subq_13.metric_time__day AS metric_time__day
  , subq_18.lux_listing__is_confirmed_lux AS listing__lux_listing__is_confirmed_lux
  , SUM(subq_13.bookings) AS bookings
FROM (
  -- Read Elements From Semantic Model 'bookings_source'
  -- Metric Time Dimension 'ds'
  -- Pass Only Elements:
  --   ['bookings', 'metric_time__day', 'listing']
  SELECT
    ds AS metric_time__day
    , listing_id AS listing
    , 1 AS bookings
  FROM ***************************.fct_bookings bookings_source_src_10015
) subq_13
LEFT OUTER JOIN (
  -- Join Standard Outputs
  -- Pass Only Elements:
  --   ['lux_listing__is_confirmed_lux',
  --    'lux_listing__window_start__day',
  --    'lux_listing__window_end__day',
  --    'listing']
  SELECT
    lux_listings_src_10019.valid_from AS lux_listing__window_start__day
    , lux_listings_src_10019.valid_to AS lux_listing__window_end__day
    , lux_listing_mapping_src_10018.listing_id AS listing
    , lux_listings_src_10019.is_confirmed_lux AS lux_listing__is_confirmed_lux
  FROM ***************************.dim_lux_listing_id_mapping lux_listing_mapping_src_10018
  LEFT OUTER JOIN
    ***************************.dim_lux_listings lux_listings_src_10019
  ON
    lux_listing_mapping_src_10018.lux_listing_id = lux_listings_src_10019.lux_listing_id
) subq_18
ON
  (
    subq_13.listing = subq_18.listing
  ) AND (
    (
      subq_13.metric_time__day >= subq_18.lux_listing__window_start__day
    ) AND (
      (
        subq_13.metric_time__day < subq_18.lux_listing__window_end__day
      ) OR (
        subq_18.lux_listing__window_end__day IS NULL
      )
    )
  )
GROUP BY
  metric_time__day
  , listing__lux_listing__is_confirmed_lux
